@@ -3,7 +3,7 @@ from __future__ import unicode_literals, absolute_import
 from bizerror.base import BizErrorBase
 from bizerror.base import set_error_info
 
-# Created: 2021-02-20 14:20:38.249000
+# Created: 2022-09-07 21:29:49.878195
 # WARNING! All changes made in this file will be lost!
 
 
@@ -20,32 +20,32 @@ set_error_info("zh-hans", "BizError", 1, "异常！")
 class SysError(BizErrorBase):
     pass
 set_error_info("en", "SysError", 1001000000, "System Error")
-set_error_info("zh-hans", "SysError", 1001000000, "系统异常")
+set_error_info("zh-hans", "SysError", 1001000000, "系统异常！")
 
 class UndefinedError(SysError):
     pass
-set_error_info("en", "UndefinedError", 1001000001, "Unknown Error")
-set_error_info("zh-hans", "UndefinedError", 1001000001, "未定义的异常")
+set_error_info("en", "UndefinedError", 1001000001, "Undefined Error")
+set_error_info("zh-hans", "UndefinedError", 1001000001, "未定义的异常！")
 
 class DatabaseError(SysError):
     pass
 set_error_info("en", "DatabaseError", 1001000002, "System Error")
-set_error_info("zh-hans", "DatabaseError", 1001000002, "数据库异常")
+set_error_info("zh-hans", "DatabaseError", 1001000002, "数据库异常！")
 
 class CacheError(SysError):
     pass
 set_error_info("en", "CacheError", 1001000003, "System Error")
-set_error_info("zh-hans", "CacheError", 1001000003, "缓存异常")
+set_error_info("zh-hans", "CacheError", 1001000003, "缓存异常！")
 
 class MessageQueueError(SysError):
     pass
 set_error_info("en", "MessageQueueError", 1001000004, "System Error")
-set_error_info("zh-hans", "MessageQueueError", 1001000004, "消息队列异常")
+set_error_info("zh-hans", "MessageQueueError", 1001000004, "消息队列异常！")
 
 class AnotherServiceError(SysError):
     pass
 set_error_info("en", "AnotherServiceError", 1001000005, "System Error")
-set_error_info("zh-hans", "AnotherServiceError", 1001000005, "外部服务异常")
+set_error_info("zh-hans", "AnotherServiceError", 1001000005, "外部服务异常！")
 
 class HttpError(BizErrorBase):
     pass
@@ -67,6 +67,21 @@ class BadResponseContent(HttpError):
 set_error_info("en", "BadResponseContent", 1001010003, "Bad response content. Content returned: {content}.")
 set_error_info("zh-hans", "BadResponseContent", 1001010003, "HTTP接口响应内容格式非法，响应报文内容为{content}。")
 
+class NoMatchingRouteFound(HttpError):
+    pass
+set_error_info("en", "NoMatchingRouteFound", 1001010004, "No matching route found.")
+set_error_info("zh-hans", "NoMatchingRouteFound", 1001010004, "未找到匹配的路由！")
+
+class ReqeustForbidden(HttpError):
+    pass
+set_error_info("en", "ReqeustForbidden", 1001010005, "Request forbidden.")
+set_error_info("zh-hans", "ReqeustForbidden", 1001010005, "拒绝访问！")
+
+class NoUpstreamServerAvailabe(HttpError):
+    pass
+set_error_info("en", "NoUpstreamServerAvailabe", 1001010006, "No upstream server availabe.")
+set_error_info("zh-hans", "NoUpstreamServerAvailabe", 1001010006, "没有找到有效的后端服务节点！")
+
 class ConfigError(BizErrorBase):
     pass
 set_error_info("en", "ConfigError", 1001020000, "Config error.")
@@ -152,45 +167,20 @@ class BadUserToken(AuthError):
 set_error_info("en", "BadUserToken", 1001040012, "Bad user token.")
 set_error_info("zh-hans", "BadUserToken", 1001040012, "用户令牌无效！")
 
+class ReqidDuplicateError(AuthError):
+    pass
+set_error_info("en", "ReqidDuplicateError", 1001040013, "Reqid duplicate error.")
+set_error_info("zh-hans", "ReqidDuplicateError", 1001040013, "请求流水号重复!")
+
 class TypeError(BizErrorBase):
     pass
 set_error_info("en", "TypeError", 1001050000, "Type error.")
 set_error_info("zh-hans", "TypeError", 1001050000, "数据类型相关异常。")
 
-class CastToIntegerFailed(TypeError):
-    pass
-set_error_info("en", "CastToIntegerFailed", 1001050001, "Cast to integer value failed on field {field}.")
-set_error_info("zh-hans", "CastToIntegerFailed", 1001050001, "字段{field}转化整数型数据失败！")
-
-class CastToFloatFailed(TypeError):
-    pass
-set_error_info("en", "CastToFloatFailed", 1001050002, "Cast to float value failed on field {field}.")
-set_error_info("zh-hans", "CastToFloatFailed", 1001050002, "字段{field}转化浮点数型数据失败！")
-
-class CastToNumbericFailed(TypeError):
-    pass
-set_error_info("en", "CastToNumbericFailed", 1001050003, "Cast to numberic value failed on field {field}.")
-set_error_info("zh-hans", "CastToNumbericFailed", 1001050003, "字段{field}转化数值型数据失败！")
-
-class CastToBooleanFailed(TypeError):
-    pass
-set_error_info("en", "CastToBooleanFailed", 1001050004, "Cast to boolean value failed on field {field}.")
-set_error_info("zh-hans", "CastToBooleanFailed", 1001050004, "字段{field}转化布尔型数据失败！")
-
-class CastToStringFailed(TypeError):
-    pass
-set_error_info("en", "CastToStringFailed", 1001050005, "Cast to string value failed on field {field}.")
-set_error_info("zh-hans", "CastToStringFailed", 1001050005, "字段{field}转化字符串型数据失败！")
-
 class ParseJsonError(TypeError):
     pass
 set_error_info("en", "ParseJsonError", 1001050006, "Parse json error. Raw text {text}.")
-set_error_info("zh-hans", "ParseJsonError", 1001050006, "Json转化异常！原始报文内容{text}。")
-
-class NotSupportedTypeToCast(TypeError):
-    pass
-set_error_info("en", "NotSupportedTypeToCast", 1001050007, "Not supported type to cast.")
-set_error_info("zh-hans", "NotSupportedTypeToCast", 1001050007, "该类型不支持转化！")
+set_error_info("zh-hans", "ParseJsonError", 1001050006, "字段{field}值为{value}{text}进行Json反序列化异常！")
 
 class ParamError(BizErrorBase):
     pass
@@ -222,6 +212,31 @@ class StringTooLong(ParamError):
 set_error_info("en", "StringTooLong", 1001060005, "String longer than {max_length}.")
 set_error_info("zh-hans", "StringTooLong", 1001060005, "参数字符数过多，最高限定为：{max_length}。")
 
+class MissingField(ParamError):
+    pass
+set_error_info("en", "MissingField", 1001060006, "Missing field: {field}.")
+set_error_info("zh-hans", "MissingField", 1001060006, "字段缺失：{field}。")
+
+class WrongFieldType(ParamError):
+    pass
+set_error_info("en", "WrongFieldType", 1001060007, "Wrong field type.")
+set_error_info("zh-hans", "WrongFieldType", 1001060007, "字段类型不匹配！")
+
+class WrongParameterType(ParamError):
+    pass
+set_error_info("en", "WrongParameterType", 1001060008, "Wrong parameter type.")
+set_error_info("zh-hans", "WrongParameterType", 1001060008, "参数类型不匹配！")
+
+class ValueExceedsMaxLimit(ParamError):
+    pass
+set_error_info("en", "ValueExceedsMaxLimit", 1001060009, "The value exceeds the upper limit.")
+set_error_info("zh-hans", "ValueExceedsMaxLimit", 1001060009, "数值{value}超过最大限制{max}！")
+
+class ValueLessThanMinLimit(ParamError):
+    pass
+set_error_info("en", "ValueLessThanMinLimit", 1001060010, "The value is less than the minimum limit.")
+set_error_info("zh-hans", "ValueLessThanMinLimit", 1001060010, "数值{value}小于最小限制{min}！")
+
 class FormError(BizErrorBase):
     pass
 set_error_info("en", "FormError", 1001070000, "Form error.")
@@ -235,14 +250,89 @@ set_error_info("zh-hans", "CaptchaOnlyAllowedOnce", 1001070001, "验证码不允
 class CaptchaValidateFailed(FormError):
     pass
 set_error_info("en", "CaptchaValidateFailed", 1001070002, "Captcha validate failed.")
-set_error_info("zh-hans", "CaptchaValidateFailed", 1001070002, "图片验证码校验失败！")
+set_error_info("zh-hans", "CaptchaValidateFailed", 1001070002, "图形验证码校验失败，请输入正确的图形验证码！")
 
 class RepeatedlySubmitForm(FormError):
     pass
 set_error_info("en", "RepeatedlySubmitForm", 1001070003, "Please do not submit a form repeatedly.")
 set_error_info("zh-hans", "RepeatedlySubmitForm", 1001070003, "请不要重复提交表单！")
 
+class CaptchaRequired(FormError):
+    pass
+set_error_info("en", "CaptchaRequired", 1001070004, "Captcha Required.")
+set_error_info("zh-hans", "CaptchaRequired", 1001070004, "启用图形验证码校验，请输入正确的验证码。")
+
 class LogicError(BizErrorBase):
     pass
 set_error_info("en", "LogicError", 1001080000, "Logic error.")
 set_error_info("zh-hans", "LogicError", 1001080000, "业务逻辑相关异常。")
+
+class CastFailedError(BizErrorBase):
+    pass
+set_error_info("en", "CastFailedError", 1001090000, "Type cast failed.")
+set_error_info("zh-hans", "CastFailedError", 1001090000, "类型转化错误。")
+
+class CastToIntegerFailed(CastFailedError):
+    pass
+set_error_info("en", "CastToIntegerFailed", 1001090001, "Cast to integer value failed on field {field} value={value}.")
+set_error_info("zh-hans", "CastToIntegerFailed", 1001090001, "字段{field}值为{value}转化整数型数据失败！")
+
+class CastToFloatFailed(CastFailedError):
+    pass
+set_error_info("en", "CastToFloatFailed", 1001090002, "Cast to float value failed on field {field} value={value}.")
+set_error_info("zh-hans", "CastToFloatFailed", 1001090002, "字段{field}值为{value}转化浮点数型数据失败！")
+
+class CastToNumbericFailed(CastFailedError):
+    pass
+set_error_info("en", "CastToNumbericFailed", 1001090003, "Cast to numberic value failed on field {field} value={value}.")
+set_error_info("zh-hans", "CastToNumbericFailed", 1001090003, "字段{field}值为{value}转化数值型数据失败！")
+
+class CastToBooleanFailed(CastFailedError):
+    pass
+set_error_info("en", "CastToBooleanFailed", 1001090004, "Cast to boolean value failed on field {field} value={value}.")
+set_error_info("zh-hans", "CastToBooleanFailed", 1001090004, "字段{field}值为{value}转化布尔型数据失败！")
+
+class CastToStringFailed(CastFailedError):
+    pass
+set_error_info("en", "CastToStringFailed", 1001090005, "Cast to string value failed on field {field} value={value}.")
+set_error_info("zh-hans", "CastToStringFailed", 1001090005, "字段{field}值为{value}转化字符串型数据失败！")
+
+class NotSupportedTypeToCast(CastFailedError):
+    pass
+set_error_info("en", "NotSupportedTypeToCast", 1001090006, "Not supported type to cast on field {field} value={value} type={type}.")
+set_error_info("zh-hans", "NotSupportedTypeToCast", 1001090006, "字段{field}值为{value}不支持转化为{type}类型！")
+
+class PermissionError(BizErrorBase):
+    pass
+set_error_info("en", "PermissionError", 1001100000, "Permission error.")
+set_error_info("zh-hans", "PermissionError", 1001100000, "权限错误。")
+
+class NoPermissionError(PermissionError):
+    pass
+set_error_info("en", "NoPermissionError", 1001100001, "No permission error.")
+set_error_info("zh-hans", "NoPermissionError", 1001100001, "无权限错误！")
+
+class NoReadPermissionError(PermissionError):
+    pass
+set_error_info("en", "NoReadPermissionError", 1001100002, "No read permission error.")
+set_error_info("zh-hans", "NoReadPermissionError", 1001100002, "没有读权限错误！")
+
+class NoWritePermissionError(PermissionError):
+    pass
+set_error_info("en", "NoWritePermissionError", 1001100003, "No write permission error.")
+set_error_info("zh-hans", "NoWritePermissionError", 1001100003, "没有写权限错误！")
+
+class NoDeletePermissionError(PermissionError):
+    pass
+set_error_info("en", "NoDeletePermissionError", 1001100004, "No delete permission error.")
+set_error_info("zh-hans", "NoDeletePermissionError", 1001100004, "没有删除权限错误！")
+
+class NoAccessPermissionError(PermissionError):
+    pass
+set_error_info("en", "NoAccessPermissionError", 1001100005, "No access permission error.")
+set_error_info("zh-hans", "NoAccessPermissionError", 1001100005, "没有访问权限错误！")
+
+class NoPermissionToCleanCacheError(PermissionError):
+    pass
+set_error_info("en", "NoPermissionToCleanCacheError", 1001100006, "No permission to clean cache error.")
+set_error_info("zh-hans", "NoPermissionToCleanCacheError", 1001100006, "没有权限清除缓存！")
